@@ -58,6 +58,7 @@ class CodeArtifact(
         self,
         scope: aws_cdk.core.Construct,
         *,
+        base_url: builtins.str,
         ingestion: aws_cdk.aws_iam.IGrantable,
         license_list: _ILicenseList_104a1518,
         monitoring: _IMonitoring_7f8300dc,
@@ -68,6 +69,7 @@ class CodeArtifact(
         '''(experimental) Binds the package source to a scope and target queue.
 
         :param scope: -
+        :param base_url: (experimental) The base URL of the bound ConstructHub instance.
         :param ingestion: (experimental) The ``IGrantable`` that will process downstream messages from the bound package source. It needs to be granted permissions to read package data from the URLs sent to the ``queue``.
         :param license_list: (experimental) The license list applied by the bound Construct Hub instance. This can be used to filter down the package only to those which will pass the license filter.
         :param monitoring: (experimental) The monitoring instance to use for registering alarms, etc.
@@ -78,6 +80,7 @@ class CodeArtifact(
         :stability: experimental
         '''
         __1 = _PackageSourceBindOptions_bccf9614(
+            base_url=base_url,
             ingestion=ingestion,
             license_list=license_list,
             monitoring=monitoring,
@@ -322,14 +325,25 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
     def __init__(
         self,
         *,
+        canary_package: typing.Optional[builtins.str] = None,
+        canary_sla: typing.Optional[aws_cdk.core.Duration] = None,
+        enable_canary: typing.Optional[builtins.bool] = None,
         staging_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
         '''
+        :param canary_package: (experimental) The package that is monitored by the package canary, if enabled by ``enableCanary``. Default: 'construct-hub-probe'
+        :param canary_sla: (experimental) The maximum amount of time it is supposed to take for packages to become visible in this ConstructHub instance. If ``enableCanary`` is enabled, an alarm will trigger if this SLA is breached by the ``canaryPackage``. Default: Duration.minutes(5)
+        :param enable_canary: (experimental) Registers a package canary, which will track availability of a canary package in ConstructHub, and emit dedicated metrics. Default: true
         :param staging_bucket: (experimental) The bucket to use for staging npm packages. Default: - a new bucket will be created.
 
         :stability: experimental
         '''
-        props = NpmJsProps(staging_bucket=staging_bucket)
+        props = NpmJsProps(
+            canary_package=canary_package,
+            canary_sla=canary_sla,
+            enable_canary=enable_canary,
+            staging_bucket=staging_bucket,
+        )
 
         jsii.create(self.__class__, self, [props])
 
@@ -338,6 +352,7 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
         self,
         scope: aws_cdk.core.Construct,
         *,
+        base_url: builtins.str,
         ingestion: aws_cdk.aws_iam.IGrantable,
         license_list: _ILicenseList_104a1518,
         monitoring: _IMonitoring_7f8300dc,
@@ -348,6 +363,7 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
         '''(experimental) Binds the package source to a scope and target queue.
 
         :param scope: -
+        :param base_url: (experimental) The base URL of the bound ConstructHub instance.
         :param ingestion: (experimental) The ``IGrantable`` that will process downstream messages from the bound package source. It needs to be granted permissions to read package data from the URLs sent to the ``queue``.
         :param license_list: (experimental) The license list applied by the bound Construct Hub instance. This can be used to filter down the package only to those which will pass the license filter.
         :param monitoring: (experimental) The monitoring instance to use for registering alarms, etc.
@@ -358,6 +374,7 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
         :stability: experimental
         '''
         __1 = _PackageSourceBindOptions_bccf9614(
+            base_url=base_url,
             ingestion=ingestion,
             license_list=license_list,
             monitoring=monitoring,
@@ -752,23 +769,76 @@ class NpmJs(metaclass=jsii.JSIIMeta, jsii_type="construct-hub.sources.NpmJs"):
 @jsii.data_type(
     jsii_type="construct-hub.sources.NpmJsProps",
     jsii_struct_bases=[],
-    name_mapping={"staging_bucket": "stagingBucket"},
+    name_mapping={
+        "canary_package": "canaryPackage",
+        "canary_sla": "canarySla",
+        "enable_canary": "enableCanary",
+        "staging_bucket": "stagingBucket",
+    },
 )
 class NpmJsProps:
     def __init__(
         self,
         *,
+        canary_package: typing.Optional[builtins.str] = None,
+        canary_sla: typing.Optional[aws_cdk.core.Duration] = None,
+        enable_canary: typing.Optional[builtins.bool] = None,
         staging_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
     ) -> None:
         '''
+        :param canary_package: (experimental) The package that is monitored by the package canary, if enabled by ``enableCanary``. Default: 'construct-hub-probe'
+        :param canary_sla: (experimental) The maximum amount of time it is supposed to take for packages to become visible in this ConstructHub instance. If ``enableCanary`` is enabled, an alarm will trigger if this SLA is breached by the ``canaryPackage``. Default: Duration.minutes(5)
+        :param enable_canary: (experimental) Registers a package canary, which will track availability of a canary package in ConstructHub, and emit dedicated metrics. Default: true
         :param staging_bucket: (experimental) The bucket to use for staging npm packages. Default: - a new bucket will be created.
 
         :stability: experimental
         '''
         self._values: typing.Dict[str, typing.Any] = {}
+        if canary_package is not None:
+            self._values["canary_package"] = canary_package
+        if canary_sla is not None:
+            self._values["canary_sla"] = canary_sla
+        if enable_canary is not None:
+            self._values["enable_canary"] = enable_canary
         if staging_bucket is not None:
             self._values["staging_bucket"] = staging_bucket
 
+    @builtins.property
+    def canary_package(self) -> typing.Optional[builtins.str]:
+        '''(experimental) The package that is monitored by the package canary, if enabled by ``enableCanary``.
+
+        :default: 'construct-hub-probe'
+
+        :stability: experimental
+        '''
+        result = self._values.get("canary_package")
+        return typing.cast(typing.Optional[builtins.str], result)
+
+    @builtins.property
+    def canary_sla(self) -> typing.Optional[aws_cdk.core.Duration]:
+        '''(experimental) The maximum amount of time it is supposed to take for packages to become visible in this ConstructHub instance.
+
+        If ``enableCanary`` is enabled, an
+        alarm will trigger if this SLA is breached by the ``canaryPackage``.
+
+        :default: Duration.minutes(5)
+
+        :stability: experimental
+        '''
+        result = self._values.get("canary_sla")
+        return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
+
+    @builtins.property
+    def enable_canary(self) -> typing.Optional[builtins.bool]:
+        '''(experimental) Registers a package canary, which will track availability of a canary package in ConstructHub, and emit dedicated metrics.
+
+        :default: true
+
+        :stability: experimental
+        '''
+        result = self._values.get("enable_canary")
+        return typing.cast(typing.Optional[builtins.bool], result)
+
     @builtins.property
     def staging_bucket(self) -> typing.Optional[aws_cdk.aws_s3.IBucket]:
         '''(experimental) The bucket to use for staging npm packages.
